import { v as value2 } from './generated-dep2.js';

console.log('dynamic2', value2);

export { value2 };
